# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20026ResponseReplicationJobs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'num_objs_updated': 'str',
        'num_bytes_transferred': 'str',
        'num_objs_deleted': 'str',
        'replication_id': 'str',
        'num_objs_timedout': 'str',
        'num_objs_errored': 'str',
        'state': 'str',
        'dest_container': 'str',
        'retries': 'str',
        'num_objs_replicated': 'str',
        'total_obj_count': 'str',
        'last_replication_time': 'str',
        'src_container': 'str',
        'remote_target_name': 'str'
    }

    attribute_map = {
        'num_objs_updated': 'num_objs_updated',
        'num_bytes_transferred': 'num_bytes_transferred',
        'num_objs_deleted': 'num_objs_deleted',
        'replication_id': 'replication_id',
        'num_objs_timedout': 'num_objs_timedout',
        'num_objs_errored': 'num_objs_errored',
        'state': 'state',
        'dest_container': 'dest_container',
        'retries': 'retries',
        'num_objs_replicated': 'num_objs_replicated',
        'total_obj_count': 'total_obj_count',
        'last_replication_time': 'last_replication_time',
        'src_container': 'src_container',
        'remote_target_name': 'remote_target_name'
    }

    def __init__(self, num_objs_updated=None, num_bytes_transferred=None, num_objs_deleted=None, replication_id=None, num_objs_timedout=None, num_objs_errored=None, state=None, dest_container=None, retries=None, num_objs_replicated=None, total_obj_count=None, last_replication_time=None, src_container=None, remote_target_name=None, _configuration=None):  # noqa: E501
        """InlineResponse20026ResponseReplicationJobs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._num_objs_updated = None
        self._num_bytes_transferred = None
        self._num_objs_deleted = None
        self._replication_id = None
        self._num_objs_timedout = None
        self._num_objs_errored = None
        self._state = None
        self._dest_container = None
        self._retries = None
        self._num_objs_replicated = None
        self._total_obj_count = None
        self._last_replication_time = None
        self._src_container = None
        self._remote_target_name = None
        self.discriminator = None

        if num_objs_updated is not None:
            self.num_objs_updated = num_objs_updated
        if num_bytes_transferred is not None:
            self.num_bytes_transferred = num_bytes_transferred
        if num_objs_deleted is not None:
            self.num_objs_deleted = num_objs_deleted
        if replication_id is not None:
            self.replication_id = replication_id
        if num_objs_timedout is not None:
            self.num_objs_timedout = num_objs_timedout
        if num_objs_errored is not None:
            self.num_objs_errored = num_objs_errored
        if state is not None:
            self.state = state
        if dest_container is not None:
            self.dest_container = dest_container
        if retries is not None:
            self.retries = retries
        if num_objs_replicated is not None:
            self.num_objs_replicated = num_objs_replicated
        if total_obj_count is not None:
            self.total_obj_count = total_obj_count
        if last_replication_time is not None:
            self.last_replication_time = last_replication_time
        if src_container is not None:
            self.src_container = src_container
        if remote_target_name is not None:
            self.remote_target_name = remote_target_name

    @property
    def num_objs_updated(self):
        """Gets the num_objs_updated of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The num_objs_updated of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._num_objs_updated

    @num_objs_updated.setter
    def num_objs_updated(self, num_objs_updated):
        """Sets the num_objs_updated of this InlineResponse20026ResponseReplicationJobs.


        :param num_objs_updated: The num_objs_updated of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._num_objs_updated = num_objs_updated

    @property
    def num_bytes_transferred(self):
        """Gets the num_bytes_transferred of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The num_bytes_transferred of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._num_bytes_transferred

    @num_bytes_transferred.setter
    def num_bytes_transferred(self, num_bytes_transferred):
        """Sets the num_bytes_transferred of this InlineResponse20026ResponseReplicationJobs.


        :param num_bytes_transferred: The num_bytes_transferred of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._num_bytes_transferred = num_bytes_transferred

    @property
    def num_objs_deleted(self):
        """Gets the num_objs_deleted of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The num_objs_deleted of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._num_objs_deleted

    @num_objs_deleted.setter
    def num_objs_deleted(self, num_objs_deleted):
        """Sets the num_objs_deleted of this InlineResponse20026ResponseReplicationJobs.


        :param num_objs_deleted: The num_objs_deleted of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._num_objs_deleted = num_objs_deleted

    @property
    def replication_id(self):
        """Gets the replication_id of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The replication_id of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._replication_id

    @replication_id.setter
    def replication_id(self, replication_id):
        """Sets the replication_id of this InlineResponse20026ResponseReplicationJobs.


        :param replication_id: The replication_id of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._replication_id = replication_id

    @property
    def num_objs_timedout(self):
        """Gets the num_objs_timedout of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The num_objs_timedout of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._num_objs_timedout

    @num_objs_timedout.setter
    def num_objs_timedout(self, num_objs_timedout):
        """Sets the num_objs_timedout of this InlineResponse20026ResponseReplicationJobs.


        :param num_objs_timedout: The num_objs_timedout of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._num_objs_timedout = num_objs_timedout

    @property
    def num_objs_errored(self):
        """Gets the num_objs_errored of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The num_objs_errored of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._num_objs_errored

    @num_objs_errored.setter
    def num_objs_errored(self, num_objs_errored):
        """Sets the num_objs_errored of this InlineResponse20026ResponseReplicationJobs.


        :param num_objs_errored: The num_objs_errored of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._num_objs_errored = num_objs_errored

    @property
    def state(self):
        """Gets the state of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The state of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20026ResponseReplicationJobs.


        :param state: The state of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def dest_container(self):
        """Gets the dest_container of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The dest_container of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._dest_container

    @dest_container.setter
    def dest_container(self, dest_container):
        """Sets the dest_container of this InlineResponse20026ResponseReplicationJobs.


        :param dest_container: The dest_container of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._dest_container = dest_container

    @property
    def retries(self):
        """Gets the retries of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The retries of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this InlineResponse20026ResponseReplicationJobs.


        :param retries: The retries of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._retries = retries

    @property
    def num_objs_replicated(self):
        """Gets the num_objs_replicated of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The num_objs_replicated of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._num_objs_replicated

    @num_objs_replicated.setter
    def num_objs_replicated(self, num_objs_replicated):
        """Sets the num_objs_replicated of this InlineResponse20026ResponseReplicationJobs.


        :param num_objs_replicated: The num_objs_replicated of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._num_objs_replicated = num_objs_replicated

    @property
    def total_obj_count(self):
        """Gets the total_obj_count of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The total_obj_count of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._total_obj_count

    @total_obj_count.setter
    def total_obj_count(self, total_obj_count):
        """Sets the total_obj_count of this InlineResponse20026ResponseReplicationJobs.


        :param total_obj_count: The total_obj_count of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._total_obj_count = total_obj_count

    @property
    def last_replication_time(self):
        """Gets the last_replication_time of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The last_replication_time of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._last_replication_time

    @last_replication_time.setter
    def last_replication_time(self, last_replication_time):
        """Sets the last_replication_time of this InlineResponse20026ResponseReplicationJobs.


        :param last_replication_time: The last_replication_time of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._last_replication_time = last_replication_time

    @property
    def src_container(self):
        """Gets the src_container of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The src_container of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._src_container

    @src_container.setter
    def src_container(self, src_container):
        """Sets the src_container of this InlineResponse20026ResponseReplicationJobs.


        :param src_container: The src_container of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._src_container = src_container

    @property
    def remote_target_name(self):
        """Gets the remote_target_name of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501


        :return: The remote_target_name of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._remote_target_name

    @remote_target_name.setter
    def remote_target_name(self, remote_target_name):
        """Sets the remote_target_name of this InlineResponse20026ResponseReplicationJobs.


        :param remote_target_name: The remote_target_name of this InlineResponse20026ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._remote_target_name = remote_target_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026ResponseReplicationJobs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026ResponseReplicationJobs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026ResponseReplicationJobs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class ExpandPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'raid_groups': 'str',
        'capacity': 'str',
        'obsdestname': 'str',
        'cloud_size': 'str',
        'sse': 'str'
    }

    attribute_map = {
        'raid_groups': 'raid_groups',
        'capacity': 'capacity',
        'obsdestname': 'obsdestname',
        'cloud_size': 'cloud_size',
        'sse': 'sse'
    }

    def __init__(self, raid_groups=None, capacity=None, obsdestname=None, cloud_size=None, sse=None, _configuration=None):  # noqa: E501
        """ExpandPool - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._raid_groups = None
        self._capacity = None
        self._obsdestname = None
        self._cloud_size = None
        self._sse = None
        self.discriminator = None

        if raid_groups is not None:
            self.raid_groups = raid_groups
        if capacity is not None:
            self.capacity = capacity
        if obsdestname is not None:
            self.obsdestname = obsdestname
        if cloud_size is not None:
            self.cloud_size = cloud_size
        if sse is not None:
            self.sse = sse

    @property
    def raid_groups(self):
        """Gets the raid_groups of this ExpandPool.  # noqa: E501

        Cannot be used with `obsdestname`. Comma separated list of RAID Group IDs.  # noqa: E501

        :return: The raid_groups of this ExpandPool.  # noqa: E501
        :rtype: str
        """
        return self._raid_groups

    @raid_groups.setter
    def raid_groups(self, raid_groups):
        """Sets the raid_groups of this ExpandPool.

        Cannot be used with `obsdestname`. Comma separated list of RAID Group IDs.  # noqa: E501

        :param raid_groups: The raid_groups of this ExpandPool.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                raid_groups is not None and not re.search(r'(?:RaidGroup-[0-9]+[,]?)+', raid_groups)):  # noqa: E501
            raise ValueError(r"Invalid value for `raid_groups`, must be a follow pattern or equal to `/(?:RaidGroup-[0-9]+[,]?)+/`")  # noqa: E501

        self._raid_groups = raid_groups

    @property
    def capacity(self):
        """Gets the capacity of this ExpandPool.  # noqa: E501

        Capacity in GB followed by the letter G.  # noqa: E501

        :return: The capacity of this ExpandPool.  # noqa: E501
        :rtype: str
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this ExpandPool.

        Capacity in GB followed by the letter G.  # noqa: E501

        :param capacity: The capacity of this ExpandPool.  # noqa: E501
        :type: str
        """

        self._capacity = capacity

    @property
    def obsdestname(self):
        """Gets the obsdestname of this ExpandPool.  # noqa: E501

        Object storage destination name. Cannot be used with `raid_groups`  # noqa: E501

        :return: The obsdestname of this ExpandPool.  # noqa: E501
        :rtype: str
        """
        return self._obsdestname

    @obsdestname.setter
    def obsdestname(self, obsdestname):
        """Sets the obsdestname of this ExpandPool.

        Object storage destination name. Cannot be used with `raid_groups`  # noqa: E501

        :param obsdestname: The obsdestname of this ExpandPool.  # noqa: E501
        :type: str
        """

        self._obsdestname = obsdestname

    @property
    def cloud_size(self):
        """Gets the cloud_size of this ExpandPool.  # noqa: E501

        Object storage size (multiple of 20).  # noqa: E501

        :return: The cloud_size of this ExpandPool.  # noqa: E501
        :rtype: str
        """
        return self._cloud_size

    @cloud_size.setter
    def cloud_size(self, cloud_size):
        """Sets the cloud_size of this ExpandPool.

        Object storage size (multiple of 20).  # noqa: E501

        :param cloud_size: The cloud_size of this ExpandPool.  # noqa: E501
        :type: str
        """

        self._cloud_size = cloud_size

    @property
    def sse(self):
        """Gets the sse of this ExpandPool.  # noqa: E501

        Encryption type.  # noqa: E501

        :return: The sse of this ExpandPool.  # noqa: E501
        :rtype: str
        """
        return self._sse

    @sse.setter
    def sse(self, sse):
        """Sets the sse of this ExpandPool.

        Encryption type.  # noqa: E501

        :param sse: The sse of this ExpandPool.  # noqa: E501
        :type: str
        """

        self._sse = sse

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExpandPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandPool):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExpandPool):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200AccessLogs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'user_id': 'str',
        'controller': 'str',
        'action': 'str',
        'access_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'user_id',
        'controller': 'controller',
        'action': 'action',
        'access_type': 'access_type'
    }

    def __init__(self, id=None, user_id=None, controller=None, action=None, access_type=None, _configuration=None):  # noqa: E501
        """InlineResponse200AccessLogs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._user_id = None
        self._controller = None
        self._action = None
        self._access_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if controller is not None:
            self.controller = controller
        if action is not None:
            self.action = action
        if access_type is not None:
            self.access_type = access_type

    @property
    def id(self):
        """Gets the id of this InlineResponse200AccessLogs.  # noqa: E501


        :return: The id of this InlineResponse200AccessLogs.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse200AccessLogs.


        :param id: The id of this InlineResponse200AccessLogs.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this InlineResponse200AccessLogs.  # noqa: E501


        :return: The user_id of this InlineResponse200AccessLogs.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this InlineResponse200AccessLogs.


        :param user_id: The user_id of this InlineResponse200AccessLogs.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def controller(self):
        """Gets the controller of this InlineResponse200AccessLogs.  # noqa: E501


        :return: The controller of this InlineResponse200AccessLogs.  # noqa: E501
        :rtype: str
        """
        return self._controller

    @controller.setter
    def controller(self, controller):
        """Sets the controller of this InlineResponse200AccessLogs.


        :param controller: The controller of this InlineResponse200AccessLogs.  # noqa: E501
        :type: str
        """

        self._controller = controller

    @property
    def action(self):
        """Gets the action of this InlineResponse200AccessLogs.  # noqa: E501


        :return: The action of this InlineResponse200AccessLogs.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this InlineResponse200AccessLogs.


        :param action: The action of this InlineResponse200AccessLogs.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def access_type(self):
        """Gets the access_type of this InlineResponse200AccessLogs.  # noqa: E501


        :return: The access_type of this InlineResponse200AccessLogs.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this InlineResponse200AccessLogs.


        :param access_type: The access_type of this InlineResponse200AccessLogs.  # noqa: E501
        :type: str
        """

        self._access_type = access_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200AccessLogs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200AccessLogs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200AccessLogs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20055(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'int',
        'message': 'str',
        'response': 'InlineResponse20055Response'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message',
        'response': 'response'
    }

    def __init__(self, status=None, message=None, response=None, _configuration=None):  # noqa: E501
        """InlineResponse20055 - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._status = None
        self._message = None
        self._response = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if message is not None:
            self.message = message
        if response is not None:
            self.response = response

    @property
    def status(self):
        """Gets the status of this InlineResponse20055.  # noqa: E501


        :return: The status of this InlineResponse20055.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20055.


        :param status: The status of this InlineResponse20055.  # noqa: E501
        :type: int
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this InlineResponse20055.  # noqa: E501


        :return: The message of this InlineResponse20055.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InlineResponse20055.


        :param message: The message of this InlineResponse20055.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def response(self):
        """Gets the response of this InlineResponse20055.  # noqa: E501


        :return: The response of this InlineResponse20055.  # noqa: E501
        :rtype: InlineResponse20055Response
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this InlineResponse20055.


        :param response: The response of this InlineResponse20055.  # noqa: E501
        :type: InlineResponse20055Response
        """

        self._response = response

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20055, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20055):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20055):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.raid_groups_api import RAIDGroupsApi  # noqa: E501
from Vpsa.rest import ApiException


class TestRAIDGroupsApi(unittest.TestCase):
    """RAIDGroupsApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.raid_groups_api.RAIDGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_hot_spare_to_raid_group(self):
        """Test case for add_hot_spare_to_raid_group

        """
        pass

    def test_create_raid_group(self):
        """Test case for create_raid_group

        """
        pass

    def test_delete_raid_group(self):
        """Test case for delete_raid_group

        """
        pass

    def test_get_drives_in_raid_group(self):
        """Test case for get_drives_in_raid_group

        """
        pass

    def test_get_free_raid_groups(self):
        """Test case for get_free_raid_groups

        """
        pass

    def test_get_raid_group(self):
        """Test case for get_raid_group

        """
        pass

    def test_get_raid_group_performance(self):
        """Test case for get_raid_group_performance

        """
        pass

    def test_pause_raid_group_media_scan(self):
        """Test case for pause_raid_group_media_scan

        """
        pass

    def test_remove_hot_spare_from_raid_group(self):
        """Test case for remove_hot_spare_from_raid_group

        """
        pass

    def test_rename_raid_group(self):
        """Test case for rename_raid_group

        """
        pass

    def test_repair_raid_group(self):
        """Test case for repair_raid_group

        """
        pass

    def test_show_raid_groups(self):
        """Test case for show_raid_groups

        """
        pass

    def test_start_raid_group_media_scan(self):
        """Test case for start_raid_group_media_scan

        """
        pass

    def test_update_raid_group_resync_speed(self):
        """Test case for update_raid_group_resync_speed

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20058ResponseUsageUsageSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'billed_amount': 'float',
        'billed_units': 'float',
        'subcategory': 'str',
        'type': 'str',
        'unit': 'str'
    }

    attribute_map = {
        'category': 'category',
        'billed_amount': 'billed_amount',
        'billed_units': 'billed_units',
        'subcategory': 'subcategory',
        'type': 'type',
        'unit': 'unit'
    }

    def __init__(self, category=None, billed_amount=None, billed_units=None, subcategory=None, type=None, unit=None, _configuration=None):  # noqa: E501
        """InlineResponse20058ResponseUsageUsageSummary - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._category = None
        self._billed_amount = None
        self._billed_units = None
        self._subcategory = None
        self._type = None
        self._unit = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if billed_amount is not None:
            self.billed_amount = billed_amount
        if billed_units is not None:
            self.billed_units = billed_units
        if subcategory is not None:
            self.subcategory = subcategory
        if type is not None:
            self.type = type
        if unit is not None:
            self.unit = unit

    @property
    def category(self):
        """Gets the category of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The category of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this InlineResponse20058ResponseUsageUsageSummary.


        :param category: The category of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def billed_amount(self):
        """Gets the billed_amount of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The billed_amount of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: float
        """
        return self._billed_amount

    @billed_amount.setter
    def billed_amount(self, billed_amount):
        """Sets the billed_amount of this InlineResponse20058ResponseUsageUsageSummary.


        :param billed_amount: The billed_amount of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: float
        """

        self._billed_amount = billed_amount

    @property
    def billed_units(self):
        """Gets the billed_units of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The billed_units of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: float
        """
        return self._billed_units

    @billed_units.setter
    def billed_units(self, billed_units):
        """Sets the billed_units of this InlineResponse20058ResponseUsageUsageSummary.


        :param billed_units: The billed_units of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: float
        """

        self._billed_units = billed_units

    @property
    def subcategory(self):
        """Gets the subcategory of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The subcategory of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._subcategory

    @subcategory.setter
    def subcategory(self, subcategory):
        """Sets the subcategory of this InlineResponse20058ResponseUsageUsageSummary.


        :param subcategory: The subcategory of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._subcategory = subcategory

    @property
    def type(self):
        """Gets the type of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The type of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20058ResponseUsageUsageSummary.


        :param type: The type of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def unit(self):
        """Gets the unit of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The unit of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this InlineResponse20058ResponseUsageUsageSummary.


        :param unit: The unit of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20058ResponseUsageUsageSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20058ResponseUsageUsageSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20058ResponseUsageUsageSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class CreateVpsaEndpointsConfForUploadTypes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'endpoints_config': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'endpoints_config': 'endpoints_config'
    }

    def __init__(self, type=None, endpoints_config=None, _configuration=None):  # noqa: E501
        """CreateVpsaEndpointsConfForUploadTypes - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._type = None
        self._endpoints_config = None
        self.discriminator = None

        self.type = type
        self.endpoints_config = endpoints_config

    @property
    def type(self):
        """Gets the type of this CreateVpsaEndpointsConfForUploadTypes.  # noqa: E501

        Upload type  # noqa: E501

        :return: The type of this CreateVpsaEndpointsConfForUploadTypes.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateVpsaEndpointsConfForUploadTypes.

        Upload type  # noqa: E501

        :param type: The type of this CreateVpsaEndpointsConfForUploadTypes.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["mag", "config"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def endpoints_config(self):
        """Gets the endpoints_config of this CreateVpsaEndpointsConfForUploadTypes.  # noqa: E501

        Endpoints configurations to set for the upload type. Each configuration must specify endpoint name. S3 endpoints configurations must also specify bucket name. Maximum to 3 endpoints. Cloud endpoints can also be specified (see 'Get cloud settings' api).  # noqa: E501

        :return: The endpoints_config of this CreateVpsaEndpointsConfForUploadTypes.  # noqa: E501
        :rtype: list[str]
        """
        return self._endpoints_config

    @endpoints_config.setter
    def endpoints_config(self, endpoints_config):
        """Sets the endpoints_config of this CreateVpsaEndpointsConfForUploadTypes.

        Endpoints configurations to set for the upload type. Each configuration must specify endpoint name. S3 endpoints configurations must also specify bucket name. Maximum to 3 endpoints. Cloud endpoints can also be specified (see 'Get cloud settings' api).  # noqa: E501

        :param endpoints_config: The endpoints_config of this CreateVpsaEndpointsConfForUploadTypes.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and endpoints_config is None:
            raise ValueError("Invalid value for `endpoints_config`, must not be `None`")  # noqa: E501

        self._endpoints_config = endpoints_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateVpsaEndpointsConfForUploadTypes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVpsaEndpointsConfForUploadTypes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVpsaEndpointsConfForUploadTypes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class JoinRemoteAuthService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_service_type': 'str',
        'auth_service_url': 'str',
        'username': 'str',
        'password': 'str',
        'project_name': 'str',
        'reseller_prefix': 'str',
        'reseller_admin_role': 'str',
        'operator_roles': 'str',
        'project_domain_id': 'str',
        'user_domain_id': 'str'
    }

    attribute_map = {
        'auth_service_type': 'auth_service_type',
        'auth_service_url': 'auth_service_url',
        'username': 'username',
        'password': 'password',
        'project_name': 'project_name',
        'reseller_prefix': 'reseller_prefix',
        'reseller_admin_role': 'reseller_admin_role',
        'operator_roles': 'operator_roles',
        'project_domain_id': 'project_domain_id',
        'user_domain_id': 'user_domain_id'
    }

    def __init__(self, auth_service_type=None, auth_service_url=None, username=None, password=None, project_name=None, reseller_prefix=None, reseller_admin_role=None, operator_roles=None, project_domain_id=None, user_domain_id=None, _configuration=None):  # noqa: E501
        """JoinRemoteAuthService - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auth_service_type = None
        self._auth_service_url = None
        self._username = None
        self._password = None
        self._project_name = None
        self._reseller_prefix = None
        self._reseller_admin_role = None
        self._operator_roles = None
        self._project_domain_id = None
        self._user_domain_id = None
        self.discriminator = None

        if auth_service_type is not None:
            self.auth_service_type = auth_service_type
        self.auth_service_url = auth_service_url
        self.username = username
        self.password = password
        self.project_name = project_name
        if reseller_prefix is not None:
            self.reseller_prefix = reseller_prefix
        if reseller_admin_role is not None:
            self.reseller_admin_role = reseller_admin_role
        if operator_roles is not None:
            self.operator_roles = operator_roles
        if project_domain_id is not None:
            self.project_domain_id = project_domain_id
        if user_domain_id is not None:
            self.user_domain_id = user_domain_id

    @property
    def auth_service_type(self):
        """Gets the auth_service_type of this JoinRemoteAuthService.  # noqa: E501

        Remote authentication service type.  # noqa: E501

        :return: The auth_service_type of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._auth_service_type

    @auth_service_type.setter
    def auth_service_type(self, auth_service_type):
        """Sets the auth_service_type of this JoinRemoteAuthService.

        Remote authentication service type.  # noqa: E501

        :param auth_service_type: The auth_service_type of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """
        allowed_values = ["ext_keystone"]  # noqa: E501
        if (self._configuration.client_side_validation and
                auth_service_type not in allowed_values):
            raise ValueError(
                "Invalid value for `auth_service_type` ({0}), must be one of {1}"  # noqa: E501
                .format(auth_service_type, allowed_values)
            )

        self._auth_service_type = auth_service_type

    @property
    def auth_service_url(self):
        """Gets the auth_service_url of this JoinRemoteAuthService.  # noqa: E501

        Authentication service endpoint URL.  # noqa: E501

        :return: The auth_service_url of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._auth_service_url

    @auth_service_url.setter
    def auth_service_url(self, auth_service_url):
        """Sets the auth_service_url of this JoinRemoteAuthService.

        Authentication service endpoint URL.  # noqa: E501

        :param auth_service_url: The auth_service_url of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and auth_service_url is None:
            raise ValueError("Invalid value for `auth_service_url`, must not be `None`")  # noqa: E501

        self._auth_service_url = auth_service_url

    @property
    def username(self):
        """Gets the username of this JoinRemoteAuthService.  # noqa: E501

        Administrator username.  # noqa: E501

        :return: The username of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this JoinRemoteAuthService.

        Administrator username.  # noqa: E501

        :param username: The username of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this JoinRemoteAuthService.  # noqa: E501

        Administrator password.  # noqa: E501

        :return: The password of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this JoinRemoteAuthService.

        Administrator password.  # noqa: E501

        :param password: The password of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def project_name(self):
        """Gets the project_name of this JoinRemoteAuthService.  # noqa: E501

        Administrator project name.  # noqa: E501

        :return: The project_name of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this JoinRemoteAuthService.

        Administrator project name.  # noqa: E501

        :param project_name: The project_name of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and project_name is None:
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    @property
    def reseller_prefix(self):
        """Gets the reseller_prefix of this JoinRemoteAuthService.  # noqa: E501

        Reseller prefix.  # noqa: E501

        :return: The reseller_prefix of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._reseller_prefix

    @reseller_prefix.setter
    def reseller_prefix(self, reseller_prefix):
        """Sets the reseller_prefix of this JoinRemoteAuthService.

        Reseller prefix.  # noqa: E501

        :param reseller_prefix: The reseller_prefix of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """

        self._reseller_prefix = reseller_prefix

    @property
    def reseller_admin_role(self):
        """Gets the reseller_admin_role of this JoinRemoteAuthService.  # noqa: E501

        Reseller admin role.  # noqa: E501

        :return: The reseller_admin_role of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._reseller_admin_role

    @reseller_admin_role.setter
    def reseller_admin_role(self, reseller_admin_role):
        """Sets the reseller_admin_role of this JoinRemoteAuthService.

        Reseller admin role.  # noqa: E501

        :param reseller_admin_role: The reseller_admin_role of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """

        self._reseller_admin_role = reseller_admin_role

    @property
    def operator_roles(self):
        """Gets the operator_roles of this JoinRemoteAuthService.  # noqa: E501

        Operator roles.  # noqa: E501

        :return: The operator_roles of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._operator_roles

    @operator_roles.setter
    def operator_roles(self, operator_roles):
        """Sets the operator_roles of this JoinRemoteAuthService.

        Operator roles.  # noqa: E501

        :param operator_roles: The operator_roles of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """

        self._operator_roles = operator_roles

    @property
    def project_domain_id(self):
        """Gets the project_domain_id of this JoinRemoteAuthService.  # noqa: E501

        Project domain ID.  # noqa: E501

        :return: The project_domain_id of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._project_domain_id

    @project_domain_id.setter
    def project_domain_id(self, project_domain_id):
        """Sets the project_domain_id of this JoinRemoteAuthService.

        Project domain ID.  # noqa: E501

        :param project_domain_id: The project_domain_id of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """

        self._project_domain_id = project_domain_id

    @property
    def user_domain_id(self):
        """Gets the user_domain_id of this JoinRemoteAuthService.  # noqa: E501

        Administrator domain ID.  # noqa: E501

        :return: The user_domain_id of this JoinRemoteAuthService.  # noqa: E501
        :rtype: str
        """
        return self._user_domain_id

    @user_domain_id.setter
    def user_domain_id(self, user_domain_id):
        """Sets the user_domain_id of this JoinRemoteAuthService.

        Administrator domain ID.  # noqa: E501

        :param user_domain_id: The user_domain_id of this JoinRemoteAuthService.  # noqa: E501
        :type: str
        """

        self._user_domain_id = user_domain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JoinRemoteAuthService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JoinRemoteAuthService):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JoinRemoteAuthService):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Zios
from Zios.api.accounts_api import AccountsApi  # noqa: E501
from Zios.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = Zios.api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_approve_request(self):
        """Test case for approve_request

        """
        pass

    def test_cleanup_account(self):
        """Test case for cleanup_account

        """
        pass

    def test_create_account(self):
        """Test case for create_account

        """
        pass

    def test_create_account_requests(self):
        """Test case for create_account_requests

        """
        pass

    def test_delete_account(self):
        """Test case for delete_account

        """
        pass

    def test_deny_request(self):
        """Test case for deny_request

        """
        pass

    def test_disable_account(self):
        """Test case for disable_account

        """
        pass

    def test_enable_account(self):
        """Test case for enable_account

        """
        pass

    def test_export_accounts_in_csv_format(self):
        """Test case for export_accounts_in_csv_format

        """
        pass

    def test_get_account(self):
        """Test case for get_account

        """
        pass

    def test_get_account_quota_details(self):
        """Test case for get_account_quota_details

        """
        pass

    def test_get_account_rate_limit(self):
        """Test case for get_account_rate_limit

        """
        pass

    def test_get_account_requests(self):
        """Test case for get_account_requests

        """
        pass

    def test_get_all_accounts(self):
        """Test case for get_all_accounts

        """
        pass

    def test_list_account_users(self):
        """Test case for list_account_users

        """
        pass

    def test_set_account_quota_by_capacity(self):
        """Test case for set_account_quota_by_capacity

        """
        pass

    def test_set_account_quota_notification_status(self):
        """Test case for set_account_quota_notification_status

        """
        pass

    def test_set_account_rate_limit(self):
        """Test case for set_account_rate_limit

        """
        pass

    def test_show_bandwidth_throughput_metering_of_account(self):
        """Test case for show_bandwidth_throughput_metering_of_account

        """
        pass

    def test_show_iops_metering_of_account(self):
        """Test case for show_iops_metering_of_account

        """
        pass

    def test_show_latency_metering_of_account(self):
        """Test case for show_latency_metering_of_account

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class ControllersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def failover_controller(self, **kwargs):  # noqa: E501
        """failover_controller  # noqa: E501

        Failover the active Controller.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.failover_controller(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FailoverController failover_controller:
        :return: InlineResponse20019
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.failover_controller_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.failover_controller_with_http_info(**kwargs)  # noqa: E501
            return data

    def failover_controller_with_http_info(self, **kwargs):  # noqa: E501
        """failover_controller  # noqa: E501

        Failover the active Controller.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.failover_controller_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FailoverController failover_controller:
        :return: InlineResponse20019
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['failover_controller']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method failover_controller" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'failover_controller' in params:
            body_params = params['failover_controller']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers/failover.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20019',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_controllers(self, **kwargs):  # noqa: E501
        """get_all_controllers  # noqa: E501

        Get a list of Controllers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_controllers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20017
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_controllers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_controllers_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_controllers_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_controllers  # noqa: E501

        Get a list of Controllers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_controllers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20017
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_controllers" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_controllers`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20017',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_controllers_virtual_networks(self, **kwargs):  # noqa: E501
        """get_all_controllers_virtual_networks  # noqa: E501

        Get a list of Controller Virtual Networks.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_controllers_virtual_networks(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20018
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_controllers_virtual_networks_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_controllers_virtual_networks_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_controllers_virtual_networks_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_controllers_virtual_networks  # noqa: E501

        Get a list of Controller Virtual Networks.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_controllers_virtual_networks_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20018
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_controllers_virtual_networks" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers/virtual_networks.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20018',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cache_performence(self, id, **kwargs):  # noqa: E501
        """get_cache_performence  # noqa: E501

        Returns the last 60 data points of cache performance data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cache_performence(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse20022
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cache_performence_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cache_performence_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_cache_performence_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_cache_performence  # noqa: E501

        Returns the last 60 data points of cache performance data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cache_performence_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse20022
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cache_performence" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_cache_performence`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^vsa-[0-9a-f]{8}_vc-[0-9]$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_cache_performence`, must conform to the pattern `/^vsa-[0-9a-f]{8}_vc-[0-9]$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_cache_performence`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers/{id}/cache_performance.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20022',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cache_stats(self, id, **kwargs):  # noqa: E501
        """get_cache_stats  # noqa: E501

        Returns the last 60 data points of cache stats data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cache_stats(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse20023
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cache_stats_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cache_stats_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_cache_stats_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_cache_stats  # noqa: E501

        Returns the last 60 data points of cache stats data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cache_stats_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse20023
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cache_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_cache_stats`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^vsa-[0-9a-f]{8}_vc-[0-9]$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_cache_stats`, must conform to the pattern `/^vsa-[0-9a-f]{8}_vc-[0-9]$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_cache_stats`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers/{id}/cache_stats.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20023',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_controllers_performance(self, id, **kwargs):  # noqa: E501
        """get_controllers_performance  # noqa: E501

        Returns the last 60 data points of performance data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_controllers_performance(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse20021
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_controllers_performance_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_controllers_performance_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_controllers_performance_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_controllers_performance  # noqa: E501

        Returns the last 60 data points of performance data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_controllers_performance_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse20021
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_controllers_performance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_controllers_performance`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^vsa-[0-9a-f]{8}_vc-[0-9]$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_controllers_performance`, must conform to the pattern `/^vsa-[0-9a-f]{8}_vc-[0-9]$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_controllers_performance`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers/{id}/performance.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20021',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lists_vcontrollers_sessions(self, id, **kwargs):  # noqa: E501
        """lists_vcontrollers_sessions  # noqa: E501

        Lists vcontroller's sessions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lists_vcontrollers_sessions(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20020
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lists_vcontrollers_sessions_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.lists_vcontrollers_sessions_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def lists_vcontrollers_sessions_with_http_info(self, id, **kwargs):  # noqa: E501
        """lists_vcontrollers_sessions  # noqa: E501

        Lists vcontroller's sessions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lists_vcontrollers_sessions_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20020
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lists_vcontrollers_sessions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `lists_vcontrollers_sessions`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^vsa-[0-9a-f]{8}_vc-[0-9]$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `lists_vcontrollers_sessions`, must conform to the pattern `/^vsa-[0-9a-f]{8}_vc-[0-9]$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vcontrollers/{id}/sessions.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20020',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class ServersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def attach_servers_to_volume(self, id, attach_servers_to_volume, **kwargs):  # noqa: E501
        """attach_servers_to_volume  # noqa: E501

        Attach Volume to Server(s).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_servers_to_volume(id, attach_servers_to_volume, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Comma_separated list of server IDs. (required)
        :param AttachServersToVolume attach_servers_to_volume: (required)
        :return: InlineResponse200166
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_servers_to_volume_with_http_info(id, attach_servers_to_volume, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_servers_to_volume_with_http_info(id, attach_servers_to_volume, **kwargs)  # noqa: E501
            return data

    def attach_servers_to_volume_with_http_info(self, id, attach_servers_to_volume, **kwargs):  # noqa: E501
        """attach_servers_to_volume  # noqa: E501

        Attach Volume to Server(s).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_servers_to_volume_with_http_info(id, attach_servers_to_volume, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Comma_separated list of server IDs. (required)
        :param AttachServersToVolume attach_servers_to_volume: (required)
        :return: InlineResponse200166
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'attach_servers_to_volume']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_servers_to_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `attach_servers_to_volume`")  # noqa: E501
        # verify the required parameter 'attach_servers_to_volume' is set
        if self.api_client.client_side_validation and ('attach_servers_to_volume' not in params or
                                                       params['attach_servers_to_volume'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `attach_servers_to_volume` when calling `attach_servers_to_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attach_servers_to_volume' in params:
            body_params = params['attach_servers_to_volume']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}/volumes.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200166',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_server(self, create_server, **kwargs):  # noqa: E501
        """create_server  # noqa: E501

        Create a new Server. IQN or iSCSI ip or FC WWPN must be provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_server(create_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateServer create_server: (required)
        :return: InlineResponse200158
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_server_with_http_info(create_server, **kwargs)  # noqa: E501
        else:
            (data) = self.create_server_with_http_info(create_server, **kwargs)  # noqa: E501
            return data

    def create_server_with_http_info(self, create_server, **kwargs):  # noqa: E501
        """create_server  # noqa: E501

        Create a new Server. IQN or iSCSI ip or FC WWPN must be provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_server_with_http_info(create_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateServer create_server: (required)
        :return: InlineResponse200158
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_server']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_server' is set
        if self.api_client.client_side_validation and ('create_server' not in params or
                                                       params['create_server'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_server` when calling `create_server`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_server' in params:
            body_params = params['create_server']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200158',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_server(self, id, **kwargs):  # noqa: E501
        """delete_server  # noqa: E501

        Delete a Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_server(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200160
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_server_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_server_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_server_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_server  # noqa: E501

        Delete a Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_server_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200160
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_server`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200160',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_server_session(self, delete_server_session, **kwargs):  # noqa: E501
        """delete_server_session  # noqa: E501

        Delete server's session.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_server_session(delete_server_session, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteServerSession delete_server_session: (required)
        :return: InlineResponse200162
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_server_session_with_http_info(delete_server_session, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_server_session_with_http_info(delete_server_session, **kwargs)  # noqa: E501
            return data

    def delete_server_session_with_http_info(self, delete_server_session, **kwargs):  # noqa: E501
        """delete_server_session  # noqa: E501

        Delete server's session.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_server_session_with_http_info(delete_server_session, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteServerSession delete_server_session: (required)
        :return: InlineResponse200162
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['delete_server_session']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_server_session" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'delete_server_session' is set
        if self.api_client.client_side_validation and ('delete_server_session' not in params or
                                                       params['delete_server_session'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_server_session` when calling `delete_server_session`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_server_session' in params:
            body_params = params['delete_server_session']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/session.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200162',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_servers(self, **kwargs):  # noqa: E501
        """get_all_servers  # noqa: E501

        Show all Servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_servers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200157
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_servers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_servers_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_servers_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_servers  # noqa: E501

        Show all Servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_servers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200157
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_servers" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_servers`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200157',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_server(self, id, **kwargs):  # noqa: E501
        """get_server  # noqa: E501

        Show a single Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_server(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200159
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_server_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_server_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_server_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_server  # noqa: E501

        Show a single Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_server_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200159
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_server`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200159',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_server_performance(self, id, **kwargs):  # noqa: E501
        """get_server_performance  # noqa: E501

        Returns the last 60 data points of performance data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_server_performance(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse200167
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_server_performance_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_server_performance_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_server_performance_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_server_performance  # noqa: E501

        Returns the last 60 data points of performance data for the specified interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_server_performance_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds.
        :return: InlineResponse200167
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_server_performance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_server_performance`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^srv-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_server_performance`, must conform to the pattern `/^srv-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_server_performance`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}/performance.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200167',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_volumes_attached_to_server(self, id, **kwargs):  # noqa: E501
        """get_volumes_attached_to_server  # noqa: E501

        Returns a list of Volumes attached to the Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_volumes_attached_to_server(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200165
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_volumes_attached_to_server_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_volumes_attached_to_server_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_volumes_attached_to_server_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_volumes_attached_to_server  # noqa: E501

        Returns a list of Volumes attached to the Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_volumes_attached_to_server_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200165
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_volumes_attached_to_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_volumes_attached_to_server`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^srv-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_volumes_attached_to_server`, must conform to the pattern `/^srv-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_volumes_attached_to_server`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}/volumes.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200165',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_server_sessions(self, id, **kwargs):  # noqa: E501
        """list_server_sessions  # noqa: E501

        Lists server's sessions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_server_sessions(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200161
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_server_sessions_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_server_sessions_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def list_server_sessions_with_http_info(self, id, **kwargs):  # noqa: E501
        """list_server_sessions  # noqa: E501

        Lists server's sessions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_server_sessions_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200161
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_server_sessions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `list_server_sessions`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^srv-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `list_server_sessions`, must conform to the pattern `/^srv-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}/sessions.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200161',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rename_server(self, id, rename_server, **kwargs):  # noqa: E501
        """rename_server  # noqa: E501

        Rename a Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_server(id, rename_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param RenameServer rename_server: (required)
        :return: InlineResponse200163
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.rename_server_with_http_info(id, rename_server, **kwargs)  # noqa: E501
        else:
            (data) = self.rename_server_with_http_info(id, rename_server, **kwargs)  # noqa: E501
            return data

    def rename_server_with_http_info(self, id, rename_server, **kwargs):  # noqa: E501
        """rename_server  # noqa: E501

        Rename a Server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_server_with_http_info(id, rename_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param RenameServer rename_server: (required)
        :return: InlineResponse200163
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'rename_server']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rename_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `rename_server`")  # noqa: E501
        # verify the required parameter 'rename_server' is set
        if self.api_client.client_side_validation and ('rename_server' not in params or
                                                       params['rename_server'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `rename_server` when calling `rename_server`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^srv-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `rename_server`, must conform to the pattern `/^srv-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rename_server' in params:
            body_params = params['rename_server']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}/rename.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200163',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_server(self, id, update_server, **kwargs):  # noqa: E501
        """update_server  # noqa: E501

        Update a Server configuration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_server(id, update_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateServer update_server: (required)
        :return: InlineResponse200164
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_server_with_http_info(id, update_server, **kwargs)  # noqa: E501
        else:
            (data) = self.update_server_with_http_info(id, update_server, **kwargs)  # noqa: E501
            return data

    def update_server_with_http_info(self, id, update_server, **kwargs):  # noqa: E501
        """update_server  # noqa: E501

        Update a Server configuration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_server_with_http_info(id, update_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateServer update_server: (required)
        :return: InlineResponse200164
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'update_server']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_server`")  # noqa: E501
        # verify the required parameter 'update_server' is set
        if self.api_client.client_side_validation and ('update_server' not in params or
                                                       params['update_server'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_server` when calling `update_server`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^srv-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `update_server`, must conform to the pattern `/^srv-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_server' in params:
            body_params = params['update_server']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/servers/{id}/config.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200164',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20020ResponseReplicationJobs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'target_name': 'str',
        'replication_id': 'str',
        'display_name': 'str',
        'state': 'str',
        'access': 'str',
        'secret': 'str',
        'dest_container': 'str',
        'region_name': 'str',
        'src_account': 'str',
        'endpoint': 'str',
        'src_container': 'str'
    }

    attribute_map = {
        'target_name': 'target_name',
        'replication_id': 'replication_id',
        'display_name': 'display_name',
        'state': 'state',
        'access': 'access',
        'secret': 'secret',
        'dest_container': 'dest_container',
        'region_name': 'region_name',
        'src_account': 'src_account',
        'endpoint': 'endpoint',
        'src_container': 'src_container'
    }

    def __init__(self, target_name=None, replication_id=None, display_name=None, state=None, access=None, secret=None, dest_container=None, region_name=None, src_account=None, endpoint=None, src_container=None, _configuration=None):  # noqa: E501
        """InlineResponse20020ResponseReplicationJobs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._target_name = None
        self._replication_id = None
        self._display_name = None
        self._state = None
        self._access = None
        self._secret = None
        self._dest_container = None
        self._region_name = None
        self._src_account = None
        self._endpoint = None
        self._src_container = None
        self.discriminator = None

        if target_name is not None:
            self.target_name = target_name
        if replication_id is not None:
            self.replication_id = replication_id
        if display_name is not None:
            self.display_name = display_name
        if state is not None:
            self.state = state
        if access is not None:
            self.access = access
        if secret is not None:
            self.secret = secret
        if dest_container is not None:
            self.dest_container = dest_container
        if region_name is not None:
            self.region_name = region_name
        if src_account is not None:
            self.src_account = src_account
        if endpoint is not None:
            self.endpoint = endpoint
        if src_container is not None:
            self.src_container = src_container

    @property
    def target_name(self):
        """Gets the target_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The target_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this InlineResponse20020ResponseReplicationJobs.


        :param target_name: The target_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def replication_id(self):
        """Gets the replication_id of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The replication_id of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._replication_id

    @replication_id.setter
    def replication_id(self, replication_id):
        """Sets the replication_id of this InlineResponse20020ResponseReplicationJobs.


        :param replication_id: The replication_id of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._replication_id = replication_id

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The display_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20020ResponseReplicationJobs.


        :param display_name: The display_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def state(self):
        """Gets the state of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The state of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20020ResponseReplicationJobs.


        :param state: The state of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def access(self):
        """Gets the access of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The access of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this InlineResponse20020ResponseReplicationJobs.


        :param access: The access of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._access = access

    @property
    def secret(self):
        """Gets the secret of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The secret of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this InlineResponse20020ResponseReplicationJobs.


        :param secret: The secret of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def dest_container(self):
        """Gets the dest_container of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The dest_container of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._dest_container

    @dest_container.setter
    def dest_container(self, dest_container):
        """Sets the dest_container of this InlineResponse20020ResponseReplicationJobs.


        :param dest_container: The dest_container of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._dest_container = dest_container

    @property
    def region_name(self):
        """Gets the region_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The region_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._region_name

    @region_name.setter
    def region_name(self, region_name):
        """Sets the region_name of this InlineResponse20020ResponseReplicationJobs.


        :param region_name: The region_name of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._region_name = region_name

    @property
    def src_account(self):
        """Gets the src_account of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The src_account of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._src_account

    @src_account.setter
    def src_account(self, src_account):
        """Sets the src_account of this InlineResponse20020ResponseReplicationJobs.


        :param src_account: The src_account of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._src_account = src_account

    @property
    def endpoint(self):
        """Gets the endpoint of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The endpoint of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this InlineResponse20020ResponseReplicationJobs.


        :param endpoint: The endpoint of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def src_container(self):
        """Gets the src_container of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501


        :return: The src_container of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :rtype: str
        """
        return self._src_container

    @src_container.setter
    def src_container(self, src_container):
        """Sets the src_container of this InlineResponse20020ResponseReplicationJobs.


        :param src_container: The src_container of this InlineResponse20020ResponseReplicationJobs.  # noqa: E501
        :type: str
        """

        self._src_container = src_container

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20020ResponseReplicationJobs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20020ResponseReplicationJobs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20020ResponseReplicationJobs):
            return True

        return self.to_dict() != other.to_dict()
